Mockintosh Control Plane

Docs
Pick any endpoint below and use "Try it out" button to send the request

| Request Count | Avg. Response Time | Response Codes

Enable tag:

Below is the config template for requests that are missing in Mockintosh config:

Enable Traffic Log

Select traffic entry from the left sidebar...

- Request Headers

- Request Body {</>} [+/-]

Response: 200

- Response Headers

- Response Body {</>} [+/-]